H_estimate_RS: Estimation of long-memory parameter

View source: R/H_estimate_RS.R

H_estimate_RSR Documentation

Estimation of long-memory parameter

Description

R/S estimate of the long-memory functional time series

Usage

H_estimate_RS(fun_dat, band_const = 1, choice_score = c("first", "average"),
    est_method = c("classical", "modified"))

Arguments

fun_dat

Functional data object on a set of discretized grid points

band_const

Constant multiplier

choice_score

First set of principal component scores or the norm of multiple principal component scores

est_method

Classical or modified R/S estimator

Value

C

Estimated covariance

score

Estimated principal component score

H_est

Estimated Hurst exponent

d_est

Estimated memory parameter

alpha_est

Estimated alpha parameter

ncomp

Number of retained components

prop_eigen_value

Proportions of eigenvalues

eigen_function

Retained principal components

Author(s)

Han Lin Shang

References

D. Li, P. M. Robinson, H. L. Shang (2020) Long-range dependent curve time series. Journal of the American Statistical Association, 115(530), 957-971.

See Also

sim_FARMA

Examples

sim_data_set = sim_FARMA(n = 50, seed_number = 123, process = "FAR")
RS_est = H_estimate_RS(sim_data_set, choice_score = "first", est_method = "classical")

ftsa documentation built on March 31, 2026, 9:07 a.m.