sim_FARMA: Simulating data from a functional autoregressive moving...

View source: R/sim_FARMA.R

sim_FARMAR Documentation

Simulating data from a functional autoregressive moving average process

Description

Simulating data from a stationary functional autoregressive moving average process

Usage

sim_FARMA(n = 500, d = 0.1, no_grid = 101, seed_number, process = c("FAR", "FARMA"))

Arguments

n

Number of curves

d

Memory parameter

no_grid

Number of grid points within a unit interval

seed_number

Psuedo-random seed number

process

FAR or FARMA process

Value

Simulated curves

Author(s)

Han Lin Shang

References

D. Li, P. M. Robinson, H. L. Shang (2020) Long-range dependent curve time series. Journal of the American Statistical Association, 115(530), 957-971.

See Also

H_estimate_RS

Examples

sim_data_set = sim_FARMA(seed_number = 123, process = "FAR")

ftsa documentation built on March 31, 2026, 9:07 a.m.