View source: R/H_estimate_RS.R
| H_estimate_RS | R Documentation |
R/S estimate of the long-memory functional time series
H_estimate_RS(fun_dat, band_const = 1, choice_score = c("first", "average"),
est_method = c("classical", "modified"))
fun_dat |
Functional data object on a set of discretized grid points |
band_const |
Constant multiplier |
choice_score |
First set of principal component scores or the norm of multiple principal component scores |
est_method |
Classical or modified R/S estimator |
C |
Estimated covariance |
score |
Estimated principal component score |
H_est |
Estimated Hurst exponent |
d_est |
Estimated memory parameter |
alpha_est |
Estimated alpha parameter |
ncomp |
Number of retained components |
prop_eigen_value |
Proportions of eigenvalues |
eigen_function |
Retained principal components |
Han Lin Shang
D. Li, P. M. Robinson, H. L. Shang (2020) Long-range dependent curve time series. Journal of the American Statistical Association, 115(530), 957-971.
sim_FARMA
sim_data_set = sim_FARMA(n = 50, seed_number = 123, process = "FAR")
RS_est = H_estimate_RS(sim_data_set, choice_score = "first", est_method = "classical")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.