powered by
R/S estimate of the long-memory functional time series
H_estimate_RS(fun_dat, band_const = 1, choice_score = c("first", "average"), est_method = c("classical", "modified"))
Estimated covariance
Estimated principal component score
Estimated Hurst exponent
Estimated memory parameter
Estimated alpha parameter
Number of retained components
Proportions of eigenvalues
Retained principal components
Functional data object on a set of discretized grid points
Constant multiplier
First set of principal component scores or the norm of multiple principal component scores
Classical or modified R/S estimator
Han Lin Shang
D. Li, P. M. Robinson, H. L. Shang (2020) Long-range dependent curve time series. Journal of the American Statistical Association, 115(530), 957-971.
sim_FARMA
sim_data_set = sim_FARMA(n = 50, seed_number = 123, process = "FAR") RS_est = H_estimate_RS(sim_data_set, choice_score = "first", est_method = "classical")
Run the code above in your browser using DataLab