| sim_FARMA | R Documentation |
Simulating data from a stationary functional autoregressive moving average process
sim_FARMA(n = 500, d = 0.1, no_grid = 101, seed_number, process = c("FAR", "FARMA"))
n |
Number of curves |
d |
Memory parameter |
no_grid |
Number of grid points within a unit interval |
seed_number |
Psuedo-random seed number |
process |
FAR or FARMA process |
Simulated curves
Han Lin Shang
D. Li, P. M. Robinson, H. L. Shang (2020) Long-range dependent curve time series. Journal of the American Statistical Association, 115(530), 957-971.
H_estimate_RS
sim_data_set = sim_FARMA(seed_number = 123, process = "FAR")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.