Learn R Programming

ftsa (version 6.7)

sim_FARMA: Simulating data from a functional autoregressive moving average process

Description

Simulating data from a stationary functional autoregressive moving average process

Usage

sim_FARMA(n = 500, d = 0.1, no_grid = 101, seed_number, process = c("FAR", "FARMA"))

Value

Simulated curves

Arguments

n

Number of curves

d

Memory parameter

no_grid

Number of grid points within a unit interval

seed_number

Psuedo-random seed number

process

FAR or FARMA process

Author

Han Lin Shang

References

D. Li, P. M. Robinson, H. L. Shang (2020) Long-range dependent curve time series. Journal of the American Statistical Association, 115(530), 957-971.

See Also

H_estimate_RS

Examples

Run this code
sim_data_set = sim_FARMA(seed_number = 123, process = "FAR")

Run the code above in your browser using DataLab